@@ -6,7 +6,7 @@ Convos - Multiuser IRC proxy with web interface
 
 =head1 VERSION
 
-0.84
+0.85
 
 =head1 DESCRIPTION
 
@@ -57,21 +57,22 @@ able to just run it:
   # Install
   $ cpanm Convos
   # Run it
-  $ convos backend &
-  $ convos daemon
+  $ convos daemon --listen http://*:8080
 
-The above works, but if you have a lot of users you probably want to use
-L<hypnotoad|Mojo::Server::Hypnotoad> instead of C<daemon>:
+The steps above will install and run Convos in a single process. This is a
+very quick way to get started, but we incourage to run Convos as one backend
+and one frontend:
 
-  $ hypnotoad $(which convos)
+  # Start the backend first
+  $ convos backend start
 
-The command above will start a full featured, UNIX optimized, preforking
-non-blocking webserver. Run the same command again, and the webserver
-will L<hot reload|Mojo::Server::Hypnotoad/USR2> the source code without
-loosing any connections.
+  # Then start the frontend
+  $ convos daemon --listen http://*:8080
 
-Convos can be configured using L<Convos::Manual::Environment>
-and L<Convos::Manual::HttpHeaders>.
+This allow you to upgrade and restart the frontend, without having to
+reconnect to the IRC servers.
+
+See L<Convos::Manual::Running> for more details.
 
 =head1 CUSTOM TEMPLATES
 
@@ -148,11 +149,10 @@ use File::Spec::Functions qw( catdir catfile tmpdir );
 use File::Basename qw( dirname );
 use Convos::Core;
 use Convos::Core::Util ();
-use Convos::Upgrader;
 
-our $VERSION = '0.84';
+our $VERSION = '0.85';
 
-$ENV{CONVOS_DEFAULT_CONNECTION} //= 'irc.perl.org:7062';
+$ENV{CONVOS_DEFAULT_CONNECTION} //= 'chat.freenode.net:6697';
 
 =head1 ATTRIBUTES
 
@@ -162,7 +162,7 @@ Holds a L<Convos::Core> object .
 
 =head2 upgrader
 
-Holds a L<Convos::Upgrader> object.
+DEPRECATED.
 
 =cut
 
@@ -175,9 +175,7 @@ has core => sub {
   $core;
 };
 
-has upgrader => sub {
-  Convos::Upgrader->new(redis => shift->redis);
-};
+has upgrader => sub { die "upgrader() is deprecated" };
 
 =head1 METHODS
 
@@ -197,20 +195,24 @@ sub startup {
 
   if (my $log = $config->{log}) {
     $self->log->level($log->{level}) if $log->{level};
-    $self->log->path($log->{file}) if $log->{file} ||= $log->{path};
+    $self->log->path($log->{file}) if $log->{file} ||= $log->{path} || $ENV{CONVOS_FRONTEND_LOGFILE};
     delete $self->log->{handle};           # make sure it's fresh to file
   }
 
   $self->ua->max_redirects(2);             # support getting facebook pictures
   $self->plugin('Convos::Plugin::Helpers');
-  $self->plugin('surveil') if $ENV{CONVOS_SURVEIL};
+  $self->plugin('LinkEmbedder');
   $self->secrets([time]);                  # will be replaced by _set_secrets()
+  $self->_redis_url;
+
+  return if $ENV{CONVOS_BACKEND_ONLY};     # set script/convos when started as backend
+
+  # frontend code
   $self->sessions->default_expiration(86400 * 30);
   $self->sessions->secure(1) if $ENV{CONVOS_SECURE_COOKIES};
   $self->_assets;
   $self->_public_routes;
   $self->_private_routes;
-  $self->_redis_url;
 
   if (!$ENV{CONVOS_INVITE_CODE} and $config->{invite_code}) {
     $self->log->warn(
@@ -226,11 +228,10 @@ sub startup {
   }
 
   $self->defaults(full_page => 1, organization_name => $self->config('name'));
-  $self->defaults(full_page => 1);
   $self->hook(before_dispatch => \&_before_dispatch);
+  $self->_embed_backend if $ENV{CONVOS_BACKEND_EMBEDDED};
 
-  Mojo::IOLoop->timer(5 => sub { $ENV{CONVOS_MANUAL_BACKEND}     or $self->_start_backend; });
-  Mojo::IOLoop->timer(0 => sub { $ENV{CONVOS_SKIP_VERSION_CHECK} or $self->_check_version; });
+  Scalar::Util::weaken($self);
   Mojo::IOLoop->timer(0 => sub { $self->_set_secrets });
 }
 
@@ -242,6 +243,7 @@ sub _assets {
   $self->asset('c.css' => qw( /scss/font-awesome.scss /sass/convos.scss ));
   $self->asset(
     'c.js' => qw(
+      https://platform.twitter.com/widgets.js
       /js/globals.js
       /js/jquery.js
       /js/ws-reconnecting.js
@@ -250,7 +252,6 @@ sub _assets {
       /js/jquery.pjax.js
       /js/jquery.notify.js
       /js/jquery.disableouterscroll.js
-      /js/selectize.js
       /js/convos.events.js
       /js/convos.sidebar.js
       /js/convos.socket.js
@@ -276,32 +277,29 @@ sub _before_dispatch {
   }
 }
 
-sub _check_version {
-  my $self = shift;
-  my $log  = $self->log;
-
-  $self->upgrader->running_latest(
-    sub {
-      my ($upgrader, $latest) = @_;
-      $latest and return;
-      $log->error(
-        "The database schema has changed.\nIt must be updated before we can start!\n\nRun '$self->{convos_executable_path} upgrade', then try again.\n\n"
-      );
-      exit;
-    },
-  );
-}
-
 sub _config {
   my $self = shift;
   my $config = $ENV{MOJO_CONFIG} ? $self->plugin('Config') : $self->config;
 
   $config->{hypnotoad}{listen} ||= [split /,/, $ENV{MOJO_LISTEN} || 'http://*:8080'];
-  $config->{name} = $ENV{CONVOS_ORGANIZATION_NAME} if $ENV{CONVOS_ORGANIZATION_NAME};
+  $config->{hypnotoad}{pid_file} = $ENV{CONVOS_FRONTEND_PID_FILE} if $ENV{CONVOS_FRONTEND_PID_FILE};
+  $config->{hypnotoad}{group}    = $ENV{RUN_AS_GROUP}             if $ENV{RUN_AS_GROUP};
+  $config->{hypnotoad}{user}     = $ENV{RUN_AS_USER}              if $ENV{RUN_AS_USER};
+  $config->{name}                = $ENV{CONVOS_ORGANIZATION_NAME} if $ENV{CONVOS_ORGANIZATION_NAME};
   $config->{name} ||= 'Nordaaker';
   $config;
 }
 
+sub _embed_backend {
+  my $self = shift;
+
+  die "Cannot start embedded backend from hypnotoad" if $SIG{USR2};
+  require Convos::Command::backend;
+  $self->{backend} = Convos::Command::backend->new(app => $self);
+  $self->{backend}->run('-f');
+  Scalar::Util::weaken($self->{backend}{app});
+}
+
 sub _from_cpan {
   my $self = shift;
   my $home = catdir dirname(__FILE__), 'Convos';
@@ -316,8 +314,6 @@ sub _private_routes {
   my $self = shift;
   my $r = $self->routes->under('/')->to('user#auth', layout => 'view');
 
-  $self->plugin('LinkEmbedder');
-
   $r->websocket('/socket')->to('chat#socket')->name('socket');
   $r->get('/chat/command-history')->to('client#command_history');
   $r->get('/chat/notifications')->to('client#notifications', layout => undef)->name('notification.list');
@@ -329,6 +325,7 @@ sub _private_routes {
   $r->post('/connection/:name/delete')->to('connection#delete_connection')->name('connection.delete');
   $r->get('/oembed')->to('oembed#generate', layout => undef)->name('oembed');
   $r->any('/profile')->to('user#edit')->name('user.edit');
+  $r->any('/profile/delete')->to('user#delete')->name('user.delete');
   $r->post('/profile/timezone/offset')->to('user#tz_offset');
   $r->get('/wizard')->to('connection#wizard')->name('wizard');
 
@@ -345,6 +342,7 @@ sub _public_routes {
   my $r = $self->routes->any->to(layout => 'tactile');
 
   $r->get('/')->to('client#route')->name('index');
+  $r->get('/convos')->to(cb => sub { shift->redirect_to('index'); });
   $r->get('/avatar')->to('user#avatar')->name('avatar');
   $r->get('/login')->to('user#login')->name('login');
   $r->post('/login')->to('user#login');
@@ -410,86 +408,6 @@ sub _set_secrets {
   );
 }
 
-sub _start_backend {
-  my $self  = shift;
-  my $redis = $self->redis;
-
-  $self->delay(
-    sub {
-      my ($delay) = @_;
-      $redis->getset('convos:backend:lock' => 1, $delay->begin);
-      $redis->get('convos:backend:pid', $delay->begin);
-      $redis->expire('convos:backend:lock' => 5);
-    },
-    sub {
-      my ($delay, $locked, $pid) = @_;
-
-      if ($pid and kill 0, $pid) {
-        $self->log->debug("Backend $pid is running.");
-      }
-      elsif ($locked) {
-        $self->log->debug('Another process is starting the backend.');
-      }
-      elsif ($SIG{USR2}) {    # hypnotoad
-        $self->_start_backend_as_external_app;
-      }
-      elsif ($ENV{CONVOS_BACKEND_EMBEDDED} or !$SIG{QUIT}) {    # forced or ./script/convos daemon
-        $self->log->debug('Starting embedded backend.');
-        $redis->set('convos:backend:pid' => $$);
-        $redis->del('convos:backend:lock');
-        $self->core->start;
-      }
-      else {                                                    # morbo
-        $self->core->reset;
-        $self->log->warn(
-          'Set CONVOS_BACKEND_EMBEDDED=1 to automatically start the backend from morbo. (The backend is not running)');
-      }
-    },
-  );
-}
-
-sub _start_backend_as_external_app {
-  my $self = shift;
-
-  local $0 = $self->{convos_executable_path};
-
-  if (!-x $0) {
-    $self->log->error("Cannot execute $0: Not executable");
-    return;
-  }
-
-  if (my $pid = fork) {
-    $self->log->debug("Starting $0 backend with double fork");
-    wait;    # wait for "fork and exit" below
-    $self->log->info("Detached $0 backend ($pid=$?)");
-    return $pid;    # parent process returns
-  }
-  elsif (!defined $pid) {
-    $self->log->error("Can't start external backend, fork failed: $!");
-    return;
-  }
-
-  # make sure the backend does not listen to the hypnotoad socket
-  Mojo::IOLoop->reset;
-
-  # start detaching new process from hypnotoad
-  if (!POSIX::setsid) {
-    $self->log->error("Can't start a new session for backend: $!");
-    exit $!;
-  }
-
-  # detach child from hypnotoad or die trying
-  defined(fork and exit) or die;
-
-  # replace fork with "convos backend" process
-  delete $ENV{MOJO_CONFIG} if $ENV{TOADFARM_APPLICATION_CLASS};
-  $ENV{CONVOS_BACKEND_EMBEDDED} = 1;
-  $self->log->debug("Replacing current process with $0 backend");
-  { exec $0 => 'backend' }
-  $self->log->error("Failed to replace current process: $!");
-  exit;
-}
-
 =head1 COPYRIGHT AND LICENSE
 
 Copyright (C) 2012-2013, Nordaaker.
